Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(398)

Unified Diff: mojo/services/view_manager/display_manager.h

Issue 510483003: Rename RootViewManager to DisplayManager (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 6 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « mojo/services/view_manager/BUILD.gn ('k') | mojo/services/view_manager/display_manager.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: mojo/services/view_manager/display_manager.h
diff --git a/mojo/services/view_manager/root_view_manager.h b/mojo/services/view_manager/display_manager.h
similarity index 74%
rename from mojo/services/view_manager/root_view_manager.h
rename to mojo/services/view_manager/display_manager.h
index 4b11d71372e4da0f5bb4c7b01d99a1909e91909f..b7ba8cf740ca1d0d6a0f796249845a52d55d544b 100644
--- a/mojo/services/view_manager/root_view_manager.h
+++ b/mojo/services/view_manager/display_manager.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef MOJO_SERVICES_VIEW_MANAGER_ROOT_VIEW_MANAGER_H_
-#define MOJO_SERVICES_VIEW_MANAGER_ROOT_VIEW_MANAGER_H_
+#ifndef MOJO_SERVICES_VIEW_MANAGER_DISPLAY_MANAGER_H_
+#define MOJO_SERVICES_VIEW_MANAGER_DISPLAY_MANAGER_H_
#include <map>
@@ -37,16 +37,16 @@ namespace service {
class Node;
class RootNodeManager;
-class RootViewManagerDelegate;
+class DisplayManagerDelegate;
-// RootViewManager binds the root node to an actual display.
-class MOJO_VIEW_MANAGER_EXPORT RootViewManager {
+// DisplayManager binds the root node to an actual display.
+class MOJO_VIEW_MANAGER_EXPORT DisplayManager {
public:
- RootViewManager(ApplicationConnection* app_connection,
+ DisplayManager(ApplicationConnection* app_connection,
RootNodeManager* root_node,
- RootViewManagerDelegate* delegate,
+ DisplayManagerDelegate* delegate,
const Callback<void()>& native_viewport_closed_callback);
- virtual ~RootViewManager();
+ virtual ~DisplayManager();
// Schedules a paint for the specified region of the specified node.
void SchedulePaint(const Node* node, const gfx::Rect& bounds);
@@ -59,7 +59,7 @@ class MOJO_VIEW_MANAGER_EXPORT RootViewManager {
void OnCompositorCreated();
- RootViewManagerDelegate* delegate_;
+ DisplayManagerDelegate* delegate_;
RootNodeManager* root_node_manager_;
@@ -76,10 +76,10 @@ class MOJO_VIEW_MANAGER_EXPORT RootViewManager {
scoped_ptr<aura::client::WindowTreeClient> window_tree_client_;
scoped_ptr<aura::client::FocusClient> focus_client_;
- DISALLOW_COPY_AND_ASSIGN(RootViewManager);
+ DISALLOW_COPY_AND_ASSIGN(DisplayManager);
};
} // namespace service
} // namespace mojo
-#endif // MOJO_SERVICES_VIEW_MANAGER_ROOT_VIEW_MANAGER_H_
+#endif // MOJO_SERVICES_VIEW_MANAGER_DISPLAY_MANAGER_H_
« no previous file with comments | « mojo/services/view_manager/BUILD.gn ('k') | mojo/services/view_manager/display_manager.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698